//>>built
define("dojo/nls/pmbdojo_sk",{"dijit/form/nls/validate":{invalidMessage:"Zadan\u00e1 hodnota nie je platn\u00e1.",missingMessage:"T\u00e1to hodnota je povinn\u00e1.",rangeMessage:"T\u00e1to hodnota je mimo rozsah.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0bil'.'",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",perMille:"\u2030",group:"\u00a0",percentFormat:"#,##0\u00a0%","decimalFormat-long":"000 bili\u00f3nov",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Predch\u00e1dzaj\u00face mo\u017enosti",
nextMessage:"Viac mo\u017enost\u00ed",_localized:{}},"dijit/nls/loading":{loadingState:"Zav\u00e1dza sa...",errorState:"\u013dutujeme, ale vyskytla sa chyba",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Zru\u0161i\u0165",buttonSave:"Ulo\u017ei\u0165",itemClose:"Zatvori\u0165",_localized:{}},"dijit/_editor/nls/commands":{bold:"Tu\u010dn\u00e9",copy:"Kop\u00edrova\u0165",cut:"Vystrihn\u00fa\u0165","delete":"Vymaza\u0165",indent:"Odsadi\u0165",insertHorizontalRule:"Vodorovn\u00e1 \u010diara",
insertOrderedList:"\u010c\u00edslovan\u00fd zoznam",insertUnorderedList:"Zoznam s odr\u00e1\u017ekami",italic:"Kurz\u00edva",justifyCenter:"Zarovna\u0165 na stred",justifyFull:"Zarovna\u0165 k okrajom",justifyLeft:"Zarovna\u0165 v\u013eavo",justifyRight:"Zarovna\u0165 vpravo",outdent:"Zmen\u0161i\u0165 odsadenie",paste:"Prilepi\u0165",redo:"Znova",removeFormat:"Odstr\u00e1ni\u0165 form\u00e1tovanie",selectAll:"Vybra\u0165 v\u0161etko",strikethrough:"Pre\u010diarknu\u0165",subscript:"Doln\u00fd index",
superscript:"Horn\u00fd index",underline:"Pod\u010diarknu\u0165",undo:"Sp\u00e4\u0165",unlink:"Odstr\u00e1ni\u0165 prepojenie",createLink:"Vytvori\u0165 prepojenie",toggleDir:"Prepn\u00fa\u0165 smer",insertImage:"Vlo\u017ei\u0165 obr\u00e1zok",insertTable:"Vlo\u017ei\u0165/upravi\u0165 tabu\u013eku",toggleTableBorder:"Prepn\u00fa\u0165 ohrani\u010denie tabu\u013eky",deleteTable:"Odstr\u00e1ni\u0165 tabu\u013eku",tableProp:"Vlastnos\u0165 tabu\u013eky",htmlToggle:"Zdrojov\u00fd k\u00f3d HTML",foreColor:"Farba popredia",
hiliteColor:"Farba pozadia",plainFormatBlock:"\u0160t\u00fdl odseku",formatBlock:"\u0160t\u00fdl odseku",fontSize:"Ve\u013ekos\u0165 p\u00edsma",fontName:"N\u00e1zov p\u00edsma",tabIndent:"Odsadenie tabul\u00e1tora",fullScreen:"Prepn\u00fa\u0165 na cel\u00fa obrazovku",viewSource:"Zobrazi\u0165 zdrojov\u00fd k\u00f3d HTML",print:"Vytla\u010di\u0165",newPage:"Nov\u00e1 str\u00e1nka",systemShortcut:'Akcia "${0}" je vo va\u0161om prehliada\u010di dostupn\u00e1 iba prostredn\u00edctvom kl\u00e1vesovej skratky. Stla\u010dte ${1}.',
ctrlKey:"Ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"xx-small",2:"x-small",3:"small",4:"medium",5:"large",6:"x-large",7:"xx-large",fontSize:"Ve\u013ekos\u0165",fontName:"P\u00edsmo",formatBlock:"Form\u00e1t",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursive",fantasy:"fantasy",noFormat:"\u017diadny",p:"Odsek",h1:"Hlavi\u010dka",h2:"Podhlavi\u010dka",h3:"Pod-podhlavi\u010dka",pre:"Predform\u00e1tovan\u00e9",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"invertovan\u00fd v\u00fdkri\u010dn\u00edk",
cent:"znak centu",pound:"znak libry",curren:"znak meny",yen:"znak yenu\nznak yuanu",brvbar:"preru\u0161ovan\u00e1 \u010diara\npreru\u0161ovan\u00e1 zvisl\u00e1 \u010diara",sect:"znak paragraf",uml:"znak prehl\u00e1skovania",copy:"znak copyright",ordf:"ordin\u00e1lny indik\u00e1tor, \u017eensk\u00fd",laquo:"znak dvojitej \u0161\u00edpky v\u013eavo\nukazovate\u013e v\u013eavo",not:"znak nie",shy:"vo\u013en\u00e1 poml\u010dka",reg:"znak registr\u00e1cie\nzna\u010dka registrovanej ochrannej zn\u00e1mky",
macr:"vodorovn\u00e1 \u010diarka",deg:"znak stupe\u0148",plusmn:"znak plus-m\u00ednus\nznak plus alebo m\u00ednus",sup2:"horn\u00fd index dva\nna druh\u00fa",sup3:"horn\u00fd index tri\nna tretiu",acute:"d\u013a\u017ee\u0148",micro:"znak mikro",para:"znak odseku",middot:"stredov\u00e1 bodka\ngregori\u00e1nska \u010diarka\ngr\u00e9cka stredov\u00e1 bodka",cedil:"cedilla\nspodn\u00fd h\u00e1\u010dik",sup1:"horn\u00fd index jedna",ordm:"ordin\u00e1lny indik\u00e1tor, mu\u017esk\u00fd",raquo:"znak dvojitej \u0161\u00edpky vpravo\nukazovate\u013e vpravo",
frac14:"jedna \u0161tvrtina",frac12:"jedna polovica",frac34:"tri \u0161tvrtiny",iquest:"invertovan\u00fd ot\u00e1znik\noto\u010den\u00fd ot\u00e1znik",Agrave:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A s opa\u010dn\u00fdm d\u013a\u017e\u0148om",Aacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A s d\u013a\u017e\u0148om",Acirc:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A so strie\u0161kou",Atilde:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A s tildou",Auml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A prehlasovan\u00e9",
Aring:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno A s kr\u00fa\u017ekom",AElig:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno AE",Ccedil:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno C so spodn\u00fdm h\u00e1\u010dikom",Egrave:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno E s opa\u010dn\u00fdm d\u013a\u017e\u0148om",Eacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno E s d\u013a\u017e\u0148om",Ecirc:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno E so strie\u0161kou",Euml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno E prehlasovan\u00e9",
Igrave:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno I s opa\u010dn\u00fdm d\u013a\u017e\u0148om",Iacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno I s d\u013a\u017e\u0148om",Icirc:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno I so strie\u0161kou",Iuml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno I prehlasovan\u00e9",ETH:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno ETH",Ntilde:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno N s tildou",Ograve:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O s opa\u010dn\u00fdm d\u013a\u017e\u0148om",
Oacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O s d\u013a\u017e\u0148om",Ocirc:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O so strie\u0161kou",Otilde:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O s tildou",Ouml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O prehlasovan\u00e9",times:"znak n\u00e1sobenia",Oslash:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno O s pre\u010diarknut\u00edm",Ugrave:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno U s opa\u010dn\u00fdm d\u013a\u017e\u0148om",Uacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno U s d\u013a\u017e\u0148om",
Ucirc:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno U so strie\u0161kou",Uuml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno U prehlasovan\u00e9",Yacute:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno Y s d\u013a\u017e\u0148om",THORN:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno THORN",szlig:"mal\u00e9 latinsk\u00e9 p\u00edsmeno ostr\u00e9 s",agrave:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a s opa\u010dn\u00fdm d\u013a\u017e\u0148om",aacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a s d\u013a\u017e\u0148om",acirc:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a so strie\u0161kou",
atilde:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a s tildou",auml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a prehlasovan\u00e9",aring:"mal\u00e9 latinsk\u00e9 p\u00edsmeno a s kr\u00fa\u017ekom",aelig:"mal\u00e9 latinsk\u00e9 p\u00edsmeno ae",ccedil:"mal\u00e9 latinsk\u00e9 p\u00edsmeno c so spodn\u00fdm h\u00e1\u010dikom",egrave:"mal\u00e9 latinsk\u00e9 p\u00edsmeno e s opa\u010dn\u00fdm d\u013a\u017e\u0148om",eacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno e s d\u013a\u017e\u0148om",ecirc:"mal\u00e9 latinsk\u00e9 p\u00edsmeno e so strie\u0161kou",
euml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno e prehlasovan\u00e9",igrave:"mal\u00e9 latinsk\u00e9 p\u00edsmeno i s opa\u010dn\u00fdm d\u013a\u017e\u0148om",iacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno i s d\u013a\u017e\u0148om",icirc:"mal\u00e9 latinsk\u00e9 p\u00edsmeno i so strie\u0161kou",iuml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno i prehlasovan\u00e9",eth:"mal\u00e9 latinsk\u00e9 p\u00edsmeno eth",ntilde:"mal\u00e9 latinsk\u00e9 p\u00edsmeno n s tildou",ograve:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o s opa\u010dn\u00fdm d\u013a\u017e\u0148om",
oacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o s d\u013a\u017e\u0148om",ocirc:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o so strie\u0161kou",otilde:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o s tildou",ouml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o prehlasovan\u00e9",divide:"znak delenia",oslash:"mal\u00e9 latinsk\u00e9 p\u00edsmeno o s pre\u010diarknut\u00edm",ugrave:"mal\u00e9 latinsk\u00e9 p\u00edsmeno u s opa\u010dn\u00fdm d\u013a\u017e\u0148om",uacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno u s d\u013a\u017e\u0148om",
ucirc:"mal\u00e9 latinsk\u00e9 p\u00edsmeno u so strie\u0161kou",uuml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno u prehlasovan\u00e9",yacute:"mal\u00e9 latinsk\u00e9 p\u00edsmeno y s d\u013a\u017e\u0148om",thorn:"mal\u00e9 latinsk\u00e9 p\u00edsmeno thorn",yuml:"mal\u00e9 latinsk\u00e9 p\u00edsmeno y prehlasovan\u00e9",fnof:"mal\u00e9 latinsk\u00e9 p\u00edsmeno f s h\u00e1\u010dikom",Alpha:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno alfa",Beta:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno beta",Gamma:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno gama",
Delta:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno delta",Epsilon:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno epsilon",Zeta:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno z\u00e9ta",Eta:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno \u00e9ta",Theta:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno t\u00e9ta",Iota:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno jota",Kappa:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno kapa",Lambda:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno lambda",Mu:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno m\u00ed",
Nu:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno n\u00ed",Xi:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno ks\u00ed",Omicron:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno omikron",Pi:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno p\u00ed",Rho:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno r\u00f3",Sigma:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno sigma",Tau:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno tau",Upsilon:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno ypsilon",Phi:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno f\u00ed",Chi:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno ch\u00ed",
Psi:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno ps\u00ed",Omega:"ve\u013ek\u00e9 gr\u00e9cke p\u00edsmeno omega",alpha:"mal\u00e9 gr\u00e9cke p\u00edsmeno alfa",beta:"mal\u00e9 gr\u00e9cke p\u00edsmeno beta",gamma:"mal\u00e9 gr\u00e9cke p\u00edsmeno gama",delta:"mal\u00e9 gr\u00e9cke p\u00edsmeno delta",epsilon:"mal\u00e9 gr\u00e9cke p\u00edsmeno epsilon",zeta:"mal\u00e9 gr\u00e9cke p\u00edsmeno z\u00e9ta",eta:"mal\u00e9 gr\u00e9cke p\u00edsmeno \u00e9ta",theta:"mal\u00e9 gr\u00e9cke p\u00edsmeno t\u00e9ta",
iota:"mal\u00e9 gr\u00e9cke p\u00edsmeno jota",kappa:"mal\u00e9 gr\u00e9cke p\u00edsmeno kapa",lambda:"mal\u00e9 gr\u00e9cke p\u00edsmeno lambda",mu:"mal\u00e9 gr\u00e9cke p\u00edsmeno m\u00ed",nu:"mal\u00e9 gr\u00e9cke p\u00edsmeno n\u00ed",xi:"mal\u00e9 gr\u00e9cke p\u00edsmeno ks\u00ed",omicron:"mal\u00e9 gr\u00e9cke p\u00edsmeno omikron",pi:"mal\u00e9 gr\u00e9cke p\u00edsmeno p\u00ed",rho:"mal\u00e9 gr\u00e9cke p\u00edsmeno r\u00f3",sigmaf:"mal\u00e9 gr\u00e9cke p\u00edsmeno sigma (koncov\u00e9)",
sigma:"mal\u00e9 gr\u00e9cke p\u00edsmeno sigma",tau:"mal\u00e9 gr\u00e9cke p\u00edsmeno tau",upsilon:"mal\u00e9 gr\u00e9cke p\u00edsmeno ypsilon",phi:"mal\u00e9 gr\u00e9cke p\u00edsmeno f\u00ed",chi:"mal\u00e9 gr\u00e9cke p\u00edsmeno ch\u00ed",psi:"mal\u00e9 gr\u00e9cke p\u00edsmeno ps\u00ed",omega:"mal\u00e9 gr\u00e9cke p\u00edsmeno omega",thetasym:"mal\u00e9 gr\u00e9cke p\u00edsmeno t\u00e9ta",upsih:"gr\u00e9cky znak ypsilon s h\u00e1\u010dikom",piv:"gr\u00e9cky symbol p\u00ed",bull:"odr\u00e1\u017eka\nmal\u00fd \u010dierny kr\u00fa\u017eok",
hellip:"tri body vodorovne",prime:"min\u00faty\nstopa",Prime:"sekundy\npalce",oline:"\u010diara nad riadkom",frasl:"lomka",weierp:"ve\u013ek\u00e9 p\u00edsan\u00e9 p\u00edsmeno P\nmocninn\u00fd rad",image:"gotick\u00e9 ve\u013ek\u00e9 p\u00edsmeno I\nimagin\u00e1rna \u010das\u0165",real:"gotick\u00e9 ve\u013ek\u00e9 p\u00edsmeno R\nre\u00e1lna \u010das\u0165",trade:"znak ochrannej zn\u00e1mky",alefsym:"symbol alef",larr:"\u0161\u00edpka do\u013eava",uarr:"\u0161\u00edpka nahor",rarr:"\u0161\u00edpka doprava",
darr:"\u0161\u00edpka nadol",harr:"\u0161\u00edpka v\u013eavo-vpravo",crarr:"lomen\u00e1 \u0161\u00edpka nadol do\u013eava\nn\u00e1vrat voz\u00edka",lArr:"dvojit\u00e1 \u0161\u00edpka do\u013eava",uArr:"dvojit\u00e1 \u0161\u00edpka nahor",rArr:"dvojit\u00e1 \u0161\u00edpka doprava",dArr:"dvojit\u00e1 \u0161\u00edpka nadol",hArr:"dvojit\u00e1 \u0161\u00edpka v\u013eavo-vpravo",forall:"pre v\u0161etky",part:"\u010diasto\u010dn\u00fd rozdiel",exist:"existuje",empty:"pr\u00e1zdna mno\u017eina\npriemer",
nabla:"nabla\nopa\u010dn\u00fd rozdiel",isin:"prvok z",notin:"nie je prvok z",ni:"obsahuje ako \u010dlen",prod:"n-\u00e1rny s\u00fa\u010din\nznak s\u00fa\u010dinu",sum:"n-\u00e1rny s\u00fa\u010det",minus:"znak m\u00ednus",lowast:"oper\u00e1tor hviezdi\u010dka",radic:"druh\u00e1 odmocnina",prop:"proporcion\u00e1lne k",infin:"nekone\u010dno",ang:"uhol",and:"logick\u00e9 a",or:"logick\u00e9 alebo",cap:"prienik",cup:"zjednotenie","int":"integr\u00e1l",there4:"preto",sim:"oper\u00e1tor tilda\nmen\u00ed sa\npodobn\u00e9",
cong:"pribli\u017ene rovn\u00e9",asymp:"takmer rovn\u00e9\nasymptotick\u00fd k",ne:"nerovn\u00fd",equiv:"identick\u00fd",le:"men\u0161\u00ed ako alebo rovn\u00fd",ge:"v\u00e4\u010d\u0161\u00ed ako alebo rovn\u00fd",sub:"podmno\u017eina",sup:"nadmno\u017eina",nsub:"nie podmno\u017eina",sube:"podmno\u017eina alebo rovn\u00e9",supe:"nadmno\u017eina alebo rovn\u00e9",oplus:"plus v kr\u00fa\u017eku\npriamy s\u00fa\u010det",otimes:"kr\u00e1t v kr\u00fa\u017eku\nvektorov\u00fd s\u00fa\u010din",perp:"oto\u010den\u00fd klin\u010dek\nortogon\u00e1lny\nkolm\u00fd",
sdot:"oper\u00e1tor bodka",lceil:"\u013eav\u00fd strop",rceil:"prav\u00fd strop",lfloor:"\u013eav\u00e1 podlaha",rfloor:"prav\u00e1 podlaha",lang:"hranat\u00e1 z\u00e1tvorka smeruj\u00faca do\u013eava",rang:"hranat\u00e1 z\u00e1tvorka smeruj\u00faca doprava",loz:"koso\u0161tvorec",spades:"\u010dierny znak pikovej karty",clubs:"\u010dierny znak kr\u00ed\u017eovej karty",hearts:"\u010dierny znak gu\u013eovej karty",diams:"\u010dierny znak k\u00e1rovej karty",OElig:"ve\u013ek\u00e1 latinsk\u00e1 ligat\u00fara OE",
oelig:"mal\u00e1 latinsk\u00e1 ligat\u00fara oe",Scaron:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno S s m\u00e4k\u010de\u0148om",scaron:"mal\u00e9 latinsk\u00e9 p\u00edsmeno s s m\u00e4k\u010de\u0148om",Yuml:"ve\u013ek\u00e9 latinsk\u00e9 p\u00edsmeno Y prehlasovan\u00e9",circ:"znak strie\u0161ky",tilde:"mal\u00e1 tilda",ensp:"kr\u00e1tka medzera",emsp:"dlh\u00e1 medzera",thinsp:"tenk\u00e1 medzera",zwnj:"nespojova\u010d nulovej d\u013a\u017eky",zwj:"spojova\u010d nulovej d\u013a\u017eky",lrm:"zna\u010dka z\u013eava-doprava",
rlm:"zna\u010dka sprava-do\u013eava",ndash:"poml\u010dka",mdash:"dlh\u00e1 poml\u010dka",lsquo:"jednoduch\u00e1 \u013eav\u00e1 \u00favodzovka",rsquo:"jednoduch\u00e1 prav\u00e1 \u00favodzovka",sbquo:"jednoduch\u00e1 doln\u00e1 \u013eav\u00e1 \u00favodzovka",ldquo:"dvojit\u00e1 \u013eav\u00e1 \u00favodzovka",rdquo:"dvojit\u00e1 prav\u00e1 \u00favodzovka",bdquo:"dvojit\u00e1 doln\u00e1 \u013eav\u00e1 \u00favodzovka",dagger:"kr\u00ed\u017eik",Dagger:"dvojit\u00fd kr\u00ed\u017eik",permil:"znak promile",
lsaquo:"jednoduch\u00fd \u013eav\u00fd ukazovate\u013e",rsaquo:"jednoduch\u00fd prav\u00fd ukazovate\u013e",euro:"znak euro",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Vlo\u017ei\u0165 symbol",_localized:{}},"dojo/nls/colors":{aliceblue:"modr\u00e1 (alice)",antiquewhite:"antick\u00e1 biela",aqua:"vodov\u00e1",aquamarine:"akvamar\u00ednov\u00e1",azure:"az\u00farov\u00e1",beige:"b\u00e9\u017eov\u00e1",bisque:"porcel\u00e1nov\u00e1",black:"\u010dierna",blanchedalmond:"bled\u00e1 mand\u013eov\u00e1",
blue:"modr\u00e1",blueviolet:"modro-fialov\u00e1",brown:"hned\u00e1",burlywood:"dreven\u00e1 hned\u00e1",cadetblue:"\u010derveno modr\u00e1",chartreuse:"kart\u00fazska",chocolate:"\u010dokol\u00e1dov\u00e1",coral:"koralov\u00e1",cornflowerblue:"nev\u00e4dzov\u00e1 modr\u00e1",cornsilk:"\u00f4stie kukurice",crimson:"karm\u00ednov\u00e1",cyan:"zelenomodr\u00e1",darkblue:"tmavomodr\u00e1",darkcyan:"tmav\u00e1 zelenomodr\u00e1",darkgoldenrod:"tmav\u00e1 zlatoby\u013e",darkgray:"tmavosiv\u00e1",darkgreen:"tmavozelen\u00e1",
darkgrey:"tmavosiv\u00e1",darkkhaki:"tmav\u00e1 \u017eltohned\u00e1",darkmagenta:"tmav\u00e1 purpurov\u00e1",darkolivegreen:"tmav\u00e1 olivovo zelen\u00e1",darkorange:"tmav\u00e1 oran\u017eov\u00e1",darkorchid:"tmav\u00e1 orchidea",darkred:"tmavo\u010derven\u00e1",darksalmon:"tmav\u00e1 lososov\u00e1",darkseagreen:"tmav\u00e1 morsk\u00e1 zelen\u00e1",darkslateblue:"tmav\u00e1 bridlicov\u00e1 modr\u00e1",darkslategray:"tmav\u00e1 bridlicov\u00e1 siv\u00e1",darkslategrey:"tmav\u00e1 bridlicov\u00e1 siv\u00e1",
darkturquoise:"tmav\u00e1 tyrkysov\u00e1",darkviolet:"tmavofialov\u00e1",deeppink:"hlbok\u00e1 ru\u017eov\u00e1",deepskyblue:"hlbok\u00e1 modr\u00e1 obloha",dimgray:"matn\u00e1 siv\u00e1",dimgrey:"matn\u00e1 siv\u00e1",dodgerblue:"modr\u00e1 (dodger)",firebrick:"p\u00e1len\u00e1 tehla",floralwhite:"biely kvet",forestgreen:"lesn\u00e1 zelen\u00e1",fuchsia:"fuchsia",gainsboro:"siv\u00e1 - gainsboro",ghostwhite:"biela (ghost white)",gold:"zlat\u00e1",goldenrod:"zlatoby\u013e",gray:"siv\u00e1",green:"zelen\u00e1",
greenyellow:"zeleno\u017elt\u00e1",grey:"siv\u00e1",honeydew:"ambr\u00f3zia",hotpink:"hor\u00faca ru\u017eov\u00e1",indianred:"indi\u00e1nska \u010derven\u00e1",indigo:"indigo",ivory:"slonovina",khaki:"kaki",lavender:"levandu\u013ea",lavenderblush:"rumencov\u00e1 levandu\u013ea",lawngreen:"tr\u00e1vov\u00e1 zelen\u00e1",lemonchiffon:"citr\u00f3nov\u00fd \u0161if\u00f3n",lightblue:"svetlomodr\u00e1",lightcoral:"svetl\u00e1 koralov\u00e1",lightcyan:"svetl\u00e1 zelenomodr\u00e1",lightgoldenrodyellow:"svetl\u00e1 zlatoby\u013eov\u00e1 \u017elt\u00e1",
lightgray:"svetlosiv\u00e1",lightgreen:"svetlozelen\u00e1",lightgrey:"svetlosiv\u00e1",lightpink:"svetloru\u017eov\u00e1",lightsalmon:"svetl\u00e1 lososov\u00e1",lightseagreen:"svetl\u00e1 morsk\u00e1 zelen\u00e1",lightskyblue:"svetl\u00e1 modr\u00e1 obloha",lightslategray:"svetl\u00e1 bridlicov\u00e1 siv\u00e1",lightslategrey:"svetl\u00e1 bridlicov\u00e1 siv\u00e1",lightsteelblue:"svetl\u00e1 oce\u013eovomodr\u00e1",lightyellow:"svetlo\u017elt\u00e1",lime:"limetkov\u00e1",limegreen:"limetkov\u00e1 zelen\u00e1",
linen:"\u013ean",magenta:"purpurov\u00e1",maroon:"ga\u0161tanov\u00e1 hned\u00e1",mediumaquamarine:"stredn\u00e1 akvamar\u00ednov\u00e1",mediumblue:"stredn\u00e1 modr\u00e1",mediumorchid:"stredn\u00e1 orchideov\u00e1",mediumpurple:"stredn\u00e1 purpurov\u00e1",mediumseagreen:"stredn\u00e1 morsk\u00e1 zelen\u00e1",mediumslateblue:"stredn\u00e1 bridlicov\u00e1 modr\u00e1",mediumspringgreen:"stredn\u00e1 jarn\u00e1 zelen\u00e1",mediumturquoise:"stredn\u00e1 tyrkysov\u00e1",mediumvioletred:"stredn\u00e1 fialovo\u010derven\u00e1",
midnightblue:"polno\u010dn\u00e1 modr\u00e1",mintcream:"m\u00e4tov\u00e1 kr\u00e9mov\u00e1",mistyrose:"zahmlen\u00e1 ru\u017ea",moccasin:"mokas\u00ednov\u00e1",navajowhite:"navajsk\u00e1 biela",navy:"n\u00e1morn\u00edcka",oldlace:"star\u00e1 \u010dipka",olive:"olivov\u00e1",olivedrab:"f\u00e1dna olivov\u00e1",orange:"oran\u017eov\u00e1",orangered:"oran\u017eovo \u010derven\u00e1",orchid:"orchideov\u00e1",palegoldenrod:"bled\u00e1 zlatoby\u013eov\u00e1",palegreen:"bled\u00e1 zelen\u00e1",paleturquoise:"bled\u00e1 tyrkysov\u00e1",
palevioletred:"bled\u00e1 fialovo \u010derven\u00e1",papayawhip:"pap\u00e1jov\u00fd kr\u00e9m",peachpuff:"brosky\u0148ov\u00fd n\u00e1dych",peru:"peru",pink:"ru\u017eov\u00e1",plum:"slivkov\u00e1",powderblue:"pr\u00e1\u0161kov\u00e1 modr\u00e1",purple:"purpurov\u00e1",red:"\u010derven\u00e1",rosybrown:"ru\u017eovo hned\u00e1",royalblue:"kr\u00e1\u013eovsk\u00e1 modr\u00e1",saddlebrown:"sedlov\u00e1 hned\u00e1",salmon:"lososov\u00e1",sandybrown:"pieskov\u00e1 hned\u00e1",seagreen:"morsk\u00e1 zelen\u00e1",
seashell:"last\u00farov\u00e1",sienna:"siensk\u00e1",silver:"strieborn\u00e1",skyblue:"modr\u00e9 nebo",slateblue:"bridlicov\u00e1 modr\u00e1",slategray:"bridlicov\u00e1 siv\u00e1",slategrey:"bridlicov\u00e1 siv\u00e1",snow:"snehov\u00e1",springgreen:"jarn\u00e1 zelen\u00e1",steelblue:"oce\u013eovomodr\u00e1",tan:"\u017eltohned\u00e1",teal:"zelenomodr\u00e1",thistle:"bodliakov\u00e1",tomato:"paradajkov\u00e1",transparent:"priesvitn\u00e1",turquoise:"tyrkysov\u00e1",violet:"fialov\u00e1",wheat:"p\u0161eni\u010dn\u00e1",
white:"biela",whitesmoke:"biely dym",yellow:"\u017elt\u00e1",yellowgreen:"\u017eltozelen\u00e1",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",greenLabel:"g",blueLabel:"b",hueLabel:"h",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"V\u00fdber odtie\u0148a",saturationPickerTitle:"V\u00fdber s\u00fdtosti",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Vlo\u017ei\u0165 tabu\u013eku",modifyTableTitle:"Upravi\u0165 tabu\u013eku",
rows:"Riadky:",columns:"St\u013apce:",align:"Zarovnanie:",cellPadding:"V\u00fdpl\u0148 buniek:",cellSpacing:"Rozstup buniek:",tableWidth:"\u0160\u00edrka tabu\u013eky:",backgroundColor:"Farba pozadia:",borderColor:"Farba r\u00e1mika:",borderThickness:"Hr\u00fabka r\u00e1mika:",percent:"percent",pixels:"pixlov","default":"predvolen\u00e9",left:"v\u013eavo",center:"stred",right:"vpravo",buttonSet:"Nastavi\u0165",buttonInsert:"Vlo\u017ei\u0165",buttonCancel:"Zru\u0161i\u0165",selectTableLabel:"Vybra\u0165 tabu\u013eku",
insertTableRowBeforeLabel:"Prida\u0165 riadok pred",insertTableRowAfterLabel:"Prida\u0165 riadok za",insertTableColumnBeforeLabel:"Prida\u0165 st\u013apec pred",insertTableColumnAfterLabel:"Prida\u0165 st\u013apec za",deleteTableRowLabel:"Vymaza\u0165 riadok",deleteTableColumnLabel:"Vymaza\u0165 st\u013apec",colorTableCellTitle:"Farba pozadia bunky tabu\u013eky",tableContextMenuTitle:"Kontextov\u00e1 ponuka tabu\u013eky",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Prilepi\u0165 z aplik\u00e1cie Word",
instructions:"Prilepte obsah z aplik\u00e1cie Word do textov\u00e9ho okienka dole. Ke\u010f ste spokojn\u00fd s obsahom na vlo\u017eenie, stla\u010dte tla\u010didlo prilepenia. Ak chcete zru\u0161i\u0165 vkladanie textu, stla\u010dte tla\u010didlo zru\u0161enia.",_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Vlo\u017ei\u0165 kotvu",title:"Vlastnosti kotvy",anchor:"N\u00e1zov:",text:"Opis:",set:"Nastavi\u0165",cancel:"Zru\u0161i\u0165",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blok cit\u00e1tu",
_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Vlo\u017ei\u0165 obr\u00e1zok",url:"Obr\u00e1zok",browse:"Preh\u013eada\u0165...",text:"Opis",set:"Vlo\u017ei\u0165",invalidMessage:"Neplatn\u00fd typ s\u00faboru obr\u00e1zka",prePopuTextUrl:"Zadajte adresu URL",prePopuTextBrowse:"alebo n\u00e1jdite lok\u00e1lny s\u00fabor.",_localized:{}}});
//# sourceMappingURL=pmbdojo_sk.js.map